@@ -2,13 +2,15 @@ from __future__ import annotations
 
 from io import IOBase
 
-from semantha_sdk.api.current_user import CurrentUserEndpoint
+from semantha_sdk.api.currentuser import CurrentuserEndpoint
+from semantha_sdk.api.celltypes import CelltypesEndpoint
 from semantha_sdk.api.diff import DiffEndpoint
 from semantha_sdk.api.info import InfoEndpoint
-from semantha_sdk.api.domain import DomainsEndpoint
+from semantha_sdk.api.languages import LanguagesEndpoint
+from semantha_sdk.api.domains import DomainsEndpoint
 from semantha_sdk.api.model import ModelEndpoint
 from semantha_sdk.api.semantha_endpoint import SemanthaAPIEndpoint
-from semantha_sdk.model.language import LanguageSchema
+from semantha_sdk.model.language_detection import LanguageDetectionSchema
 from semantha_sdk.rest.rest_client import RestClient
 
 
@@ -24,20 +26,26 @@ class SemanthaAPI(SemanthaAPIEndpoint):
 
     def __init__(self, session: RestClient, parent_endpoint: str, endpoint_without_version: str):
         super().__init__(session, parent_endpoint)
-        self.__current_user = CurrentUserEndpoint(session, self._endpoint)
+        self.__current_user = CurrentuserEndpoint(session, self._endpoint)
         self.__diff = DiffEndpoint(session, self._endpoint)
         self.__domains = DomainsEndpoint(session, self._endpoint)
         self.__model = ModelEndpoint(session, self._endpoint)
         self.__info = InfoEndpoint(session, endpoint_without_version)
+        self.__languages = LanguagesEndpoint(session, self._endpoint);
+        self.__celltypes = CelltypesEndpoint(session, self._endpoint);
 
     @property
     def _endpoint(self):
         return self._parent_endpoint
 
     @property
-    def currentuser(self) -> CurrentUserEndpoint:
+    def currentuser(self) -> CurrentuserEndpoint:
         return self.__current_user
 
+    @property
+    def celltypes(self) -> CelltypesEndpoint:
+        return self.__celltypes
+
     @property
     def domains(self) -> DomainsEndpoint:
         return self.__domains
@@ -54,8 +62,6 @@ class SemanthaAPI(SemanthaAPIEndpoint):
     def info(self) -> InfoEndpoint:
         return self.__info
 
-    def languages(self, file: IOBase):
-        endpoint = f"{self._endpoint}/languages"
-        return self._session.post(endpoint, body={
-            "file": file
-        }).execute().to(LanguageSchema)
+    @property
+    def languages(self) -> LanguagesEndpoint:
+        return self.__languages
\ No newline at end of file
