@@ -1,14 +1,17 @@
+
 from dataclasses import dataclass
 
 from marshmallow_dataclass import class_schema
 
 from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
 
+from typing import Optional
+
 
 @dataclass(frozen=True)
 class Entity(SemanthaModelEntity):
-    id: str
+    """ author semantha, this is a generated class do not change manually! """
+    id: Optional[str]
     name: str
 
-
 EntitySchema = class_schema(Entity, base_schema=SemanthaSchema)
