@@ -1,23 +1,28 @@
+
 from dataclasses import dataclass
-from typing import List, Any, Optional
 
 from marshmallow_dataclass import class_schema
 
-from semantha_sdk.model import SemanthaModelEntity, Metadata, Label
+from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
+
 from semantha_sdk.model.complex_property import ComplexProperty
 from semantha_sdk.model.extraction_reference import ExtractionReference
 from semantha_sdk.model.file_reference import FileReference
 from semantha_sdk.model.finding import Finding
+from semantha_sdk.model.label import Label
 from semantha_sdk.model.linked_instance import LinkedInstance
-from semantha_sdk.model.semantha_entity import SemanthaSchema
+from semantha_sdk.model.metadata import Metadata
 from semantha_sdk.model.simple_property import SimpleProperty
+from typing import List
+from typing import Optional
 
 
 @dataclass(frozen=True)
 class ModelInstance(SemanthaModelEntity):
+    """ author semantha, this is a generated class do not change manually! """
     id: Optional[str]
-    name: Optional[str]
-    class_id: Optional[str]
+    name: str
+    class_id: str
     relation_id: Optional[str]
     type: Optional[str]
     ignore_import: Optional[bool]
@@ -33,4 +38,4 @@ class ModelInstance(SemanthaModelEntity):
     references: Optional[List[ExtractionReference]]
     linked_instances: Optional[List[LinkedInstance]]
 
-ModelInstanceSchema = class_schema(ModelInstance, base_schema=SemanthaSchema)
\ No newline at end of file
+ModelInstanceSchema = class_schema(ModelInstance, base_schema=SemanthaSchema)
