@@ -1,22 +1,24 @@
+
 from dataclasses import dataclass
-from typing import Any, List
 
 from marshmallow_dataclass import class_schema
 
-from semantha_sdk.model import SemanthaModelEntity
+from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
+
 from semantha_sdk.model.extraction_file import ExtractionFile
 from semantha_sdk.model.model_instance import ModelInstance
 from semantha_sdk.model.process_information import ProcessInformation
-from semantha_sdk.model.semantha_entity import SemanthaSchema
 from semantha_sdk.model.table_instance import TableInstance
+from typing import List
+from typing import Optional
 
 
 @dataclass(frozen=True)
 class SemanticModel(SemanthaModelEntity):
-    files: List[ExtractionFile]
-    instances: List[ModelInstance]
-    tables: List[TableInstance]
-    process_information: ProcessInformation
+    """ author semantha, this is a generated class do not change manually! """
+    files: Optional[List[ExtractionFile]]
+    instances: Optional[List[ModelInstance]]
+    tables: Optional[List[TableInstance]]
+    process_information: Optional[ProcessInformation]
 
-
-SemanticModelSchema = class_schema(SemanticModel, base_schema=SemanthaSchema)
\ No newline at end of file
+SemanticModelSchema = class_schema(SemanticModel, base_schema=SemanthaSchema)
