@@ -1,24 +1,25 @@
-from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Optional, List
 
 from marshmallow_dataclass import class_schema
 
-from semantha_sdk.model.named_entity import NamedEntity
-from semantha_sdk.model.reference import Reference
 from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
-from semantha_sdk.model.area import Area
+
+from semantha_sdk.model.document_named_entity import DocumentNamedEntity
+from semantha_sdk.model.rect import Rect
+from semantha_sdk.model.reference import Reference
+from typing import List
+from typing import Optional
 
 
 @dataclass(frozen=True)
 class Sentence(SemanthaModelEntity):
-    id: str
-    text: str
+    """ author semantha, this is a generated class do not change manually! """
+    id: Optional[str]
+    text: Optional[str]
     document_name: Optional[str]
-    named_entities: Optional[List[NamedEntity]]
+    named_entities: Optional[List[DocumentNamedEntity]]
     references: Optional[List[Reference]]
-    areas: Optional[List[Area]]
-
+    areas: Optional[List[Rect]]
 
 SentenceSchema = class_schema(Sentence, base_schema=SemanthaSchema)
