@@ -1,16 +1,17 @@
+
 from dataclasses import dataclass
 
 from marshmallow_dataclass import class_schema
 
-from semantha_sdk.model import SemanthaModelEntity
-from semantha_sdk.model.semantha_entity import SemanthaSchema
+from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
+
 
 
 @dataclass(frozen=True)
 class SimpleProperty(SemanthaModelEntity):
+    """ author semantha, this is a generated class do not change manually! """
     name: str
     value: str
     property_id: str
 
-
-SimplePropertySchema = class_schema(SimpleProperty, base_schema=SemanthaSchema)
\ No newline at end of file
+SimplePropertySchema = class_schema(SimpleProperty, base_schema=SemanthaSchema)
