@@ -1,20 +1,21 @@
-from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import Optional, List
 
 from marshmallow_dataclass import class_schema
 
 from semantha_sdk.model.semantha_entity import SemanthaModelEntity, SemanthaSchema
 
+from typing import List
+from typing import Optional
+
 
 @dataclass(frozen=True)
 class Synonym(SemanthaModelEntity):
-    id: str
+    """ author semantha, this is a generated class do not change manually! """
+    id: Optional[str]
     word: Optional[str]
     regex: Optional[str]
-    synonym: str
-    tags: List[str]
-
+    synonym: Optional[str]
+    tags: Optional[List[str]]
 
 SynonymSchema = class_schema(Synonym, base_schema=SemanthaSchema)
