@@ -32,7 +32,12 @@ def _filter_json(data: dict):
     data = {k: v for k, v in data.items() if v is not None}
     return data
 
-
+class MediaType:
+    XLSX = "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet"
+    JSON = "application/json"
+    PDF = "application/pdf"
+    DOCX = "application/vnd.openxmlformats-officedocument.wordprocessingml.document"
+    
 class RestClient:
 
     def __init__(self, server_url: str, api_key: str):
@@ -44,6 +49,11 @@ class RestClient:
             'Accept': 'application/json',
             'Authorization': f'Bearer {self.__api_key}'
         }
+        
+    def __build_headers_for_request(self) -> dict[str, str]:
+        return {
+            'Authorization': f'Bearer {self.__api_key}'
+        }
 
     def __request(self,
                   method,
@@ -60,7 +70,7 @@ class RestClient:
         if headers is None:
             headers = self.__build_headers_for_json_request()
         else:
-            headers = {**headers, **self.__build_headers_for_json_request()}
+            headers = {**headers, **self.__build_headers_for_request()}
 
         if json is not None:
             json = _filter_json(json)
@@ -117,3 +127,6 @@ class RestClient:
         if body is None and json is None:
             raise ValueError("Either a body (files/form-data) or a json must be provided!")
         return self.__request("PUT", url, files=body, json=json, params=q_params)
+
+    def to_header(accept_mime_type: str):
+        return {"Accept": accept_mime_type}
